#
# spec file for package squirrel
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


### Upstream doesn't version the library and changes ABI
### bump this version on every version update or check that it should remain
### Re-run %%setup (quilt setup) after each update
%define sover 1001

# Disable LTO optimizations
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects

%define tarver 3_2
Name:           squirrel
Version:        3.2
Release:        3.2
Summary:        A high level imperative/OO programming language
License:        MIT
Group:          Development/Languages/Other
URL:            https://squirrel-lang.org/
Source:         https://downloads.sourceforge.net/squirrel/squirrel_%{tarver}_stable.tar.gz
Source1:        squirrel-config.cmake.in
Source10:       sover.patch.in
Source11:       squirrel.rpmlintrc
Patch1:         c++11.patch
# Generated from S:10 in %%prep, so update that if patch no longer applies
Patch10:        sover.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  sed

%description
Squirrel is a programming language featuring higher-order functions,
classes, inheritance, delegation, tail recursion, generators,
cooperative threads, exception handling, reference counting, garbage
collection on demand, and a C-like syntax.

%package        -n libsquirrel%{sover}
Summary:        Development files for %{name}

%description -n libsquirrel%{sover}
This package contains runtime library for Squirrel

%package        devel
Summary:        Development files for %{name}
Requires:       libsquirrel%{sover} = %{version}

%description devel
This package contains everything to embed the Squirrel engine in
your own application.

%package        doc
Summary:        Documentation for %{name}
Supplements:    %{name} = %{version}
BuildArch:      noarch

%description doc
Documentation files for squirrel.

%package        examples
Summary:        Example scripts for %{name}
Suggests:       %{name} = %{version}
BuildArch:      noarch

%description examples
Example scripts to show squirrel usage.

%prep
%setup -q -n squirrel3
sed -e 's,1000,%{sover},g' < %{_sourcedir}/sover.patch.in > %{_sourcedir}/sover.patch
%patch -P 1 -p1
%patch -P 10 -p1
cp %SOURCE1 .

%build
%cmake \
    -DDISABLE_STATIC=1 \
    -DLONG_OUTPUT_NAMES=1
make %{?_smp_mflags}

%install
%cmake_install
# compat link for older distros
%if %suse_version < 1599
ln -s /usr/bin/squirrel3 %{buildroot}%{_bindir}/sqrl
%endif

%post -n libsquirrel%{sover} -p /sbin/ldconfig
%postun -n libsquirrel%{sover} -p /sbin/ldconfig

%files
%{_bindir}/squirrel3
%if %suse_version < 1599
%{_bindir}/sqrl
%endif

%files -n libsquirrel%{sover}
%license COPYRIGHT
%{_libdir}/*.so.%{sover}
%{_libdir}/*.so.%{sover}.*

%files devel
%dir %{_libdir}/cmake
%dir %{_libdir}/cmake/squirrel
%{_includedir}/sq*.h
%{_libdir}/*.so
%{_libdir}/cmake/squirrel/*

%files doc
%license COPYRIGHT
%doc README HISTORY
%doc doc/*

%files examples
%license COPYRIGHT
%doc samples/*

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Mar 20 2023 Adam Majer <adam.majer@suse.de>
- spec file changes:
  * drop static library because everything that needs maintenance
    patch is then vulnerable without rebuild (see bug that was just patched)
  * drop Group since it was wrong anyway
  * move runtime library to its won subpackage from executable
  * switch to cmake
  * update sover ourselves since upstream doesn't do this and
    seems to break ABI between versions.
- c++11.patch: drop C++11 standard in favour of latest
- sover.patch: patch to update sover on version updates, generated
  from sover.patch.in during setup
- squirrel-gcc47.patch: dropped, fixed upstream
- squirrel-autoconfiscate.patch: dropped, obsolete
- squirrel-rename_binary.patch: dropped, obsolete
- squirrel-config.cmake.in: add missing file
- squirrel.rpmlintrc: ignore EOL warnings in doc files
* Fri Jan 13 2023 Dirk Müller <dmueller@suse.com>
- update to 3.2 (bsc#1201974, CVE-2021-41556):
  * added new inline bind env syntax for closures
  * added sq_tailcall
  * added rawcall keyword
  * added post call initializer syntax
  * added table.keys() and table.values()
  * added table.filter()
  * added skipempty in split()
  * additional parameters in array.map() and array.apply()
  * additional optional initializer in array.reduce()
  * added sqstd_pushstringf and sqstd_throwerrorf
  * closure.call() is now a "native tailcall" and the invoked function can now be suspended
  * fixed sq_newmember and sq_rawnewmember properly pop parameters
  * fixed capturing free variable on for loop counter before a break statement
  * fixed \u in lexer
  * various bugfixes
  * sq_gettypetag doesn't set last error(it's treated as SQBool function but keeps a SQRESULT for backward compatibility)
  * fixed _set method in userdata delegates
  * fixed some warnings
- drop squirrel-aliasing.patch, squirrel-ptr_conversion.patch (upstream)
* Tue Oct  1 2019 Jan Engelhardt <jengelh@inai.de>
- Drop %%defattr, drop *.la files, trim bias from description.
* Wed Sep 18 2019 Christophe Giboudeaux <christophe@krop.fr>
- Fix the download URL
* Tue Sep 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Use -ffat-lto-objects when building static libraries.
- Run spec-cleaner
* Thu Mar 26 2015 p.drouand@gmail.com
- Update to version 3.0.7
  * newthread and sq_newthread() no longer resets the base lib
    function in the root table
  * exceptions in the _inherited metamethod are propagated
  * 'in' operator performance improvement
  * fixed bug in print()
  * fixed some documentation bug
- Use download Url as source
- Update patches;
  * squirrel-gcc47.patch
  * squirrel-ptr_conversion.patch
* Wed Jul 24 2013 coolo@suse.com
- the dirname macro is something special in rpm 4.11, so rename
  the macro to fix build
* Wed May  2 2012 joop.boonen@opensuse.org
- update to version 3.0.2
  + added sq_gethash API
  + now array.sort() is implemented with heapsort
  + now floats in scientific notation also accept numbers with no '.' (eg. 1e+6 or 1e6)
  + fixed some warning
  + fixed some documentation
  + fixed bug in GC
* Sat Mar 24 2012 dimstar@opensuse.org
- Add squirrel-gcc47.patch: Fix build with gcc 4.7.
* Mon Nov 28 2011 coolo@suse.com
- calling autoreconf after patching all about auto* sounds sane
* Tue Nov 15 2011 pth@suse.de
- Change license to MIT (bnc#730449).
* Tue Nov 15 2011 pth@suse.de
- Add copyright to spec file.
* Mon Nov 14 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Thu Nov 10 2011 pth@suse.de
- Autoconfiscate the package so that handling of libraries and
  installation gets easier.
- Include cstdint/stdint.h and define squirrel types using the
  * _t macros.
- Rename the sq binary to sqrl to fix conflict with ispell.
- Fix aliasing issues by using unions.
* Thu Aug 25 2011 lars@linux-schulserver.de
- update to 3.0: please refer to
  /usr/share/doc/packages/squirrel/HISTORY for all the changes
- split out doc package with all the reference and standard
  libraries manuals
* Sat Sep 26 2009 lars@linux-schulserver.de
- update to 2.2.3
  + added sq_getfunctioninfo
  + added compile time flag SQUSEDOUBLE to use double precision floats
  + added global slot _floatsize_ int the base lib to recognize single
    precision and double precision builds
  + sq_wakeupvm can now resume the vm with an exception
  + added sqstd_format
  + generators can now be instantiated by calling sq_call() or closure.call()
  + fixed a bug in sqstd_printcallstack(thx takayuki_h)
  + fixed modulo by zero(thx jup)
  + fixed negative enums and constants
  + fixed generator crash bug if invoked as tail call (thx Mr.Accident)
  + fixed some minor bug
* Sat Jul 12 2008 lars@linux-schulserver.de
- update to 2.2.1:
  + fixed a tailcall bug
* Fri Mar 21 2008 lars@linux-schulserver.de
- update to 2.2
* Tue Dec 25 2007 lars@linux-schulserver.de
- initial version 2.1.2
